@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,14 +18,23 @@
 
 """Base class for classes that need modular database access."""
 
-import cinder.db
+from cinder import flags
+from cinder.openstack.common import cfg
+from cinder.openstack.common import importutils
+
+
+db_driver_opt = cfg.StrOpt('db_driver',
+                           default='cinder.db',
+                           help='driver to use for database access')
+
+FLAGS = flags.FLAGS
+FLAGS.register_opt(db_driver_opt)
 
 
 class Base(object):
     """DB driver is injected in the init method."""
 
-    def __init__(self):
-        super().__init__()
-
-        self.db = cinder.db
-        self.db.dispose_engine()
+    def __init__(self, db_driver=None):
+        if not db_driver:
+            db_driver = FLAGS.db_driver
+        self.db = importutils.import_module(db_driver)  # pylint: disable=C0103
